# cli

The Probo Command Line Interface (PCLI) is designed for rapid scaffolding, JIT styling, and static site generation. It centers around the Template Component Map (TCM) to automate the bridge between your Python components and the final web output.

::: probo.terminal.cli
